-- 玲珑宝塔临时仓库
Lua_ExquisitePagodaPackWindow = class("Lua_ExquisitePagodaPackWindow", Lua_ThirdSizeWindow);
function Lua_ExquisitePagodaPackWindow:ctor()
	self:superCall("ctor", true, 3500, true, LanUtil.getValue(121416));

	self.windowName = "Lua_ExquisitePagodaPackWindow";
	self.skinName = "ExquisitePagodaPackWindow_skin";
	self.w = 600;
	self.h = 499;
	self.isClickClose = false;
end

function Lua_ExquisitePagodaPackWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.desLab.text = LanUtil.getValue(121414);

	local onePageCount = Lua_CommonUtil.getCommonConfig("pagoda_package_size", 1); -- 168
	local horizontalNum = 7;
	local verticalNum = 4;
	self.pageLen = math.ceil(onePageCount / (horizontalNum * verticalNum));
	
	local pageIcon
	local perWidth = 22;
	self.pageTipList = Array();
	for i = 1, self.pageLen do
		pageIcon = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_b_1", 0, 0, 0, 0);
		pageIcon.name = i;
		pageIcon:setDepth(5);
		pageIcon:setLocation(-perWidth * self.pageLen / 2 + perWidth * (i - 1) + perWidth / 2, -145, 0);
		pageIcon:addClickFuntion(self, self.onPageClick);
		self.pageTipList:add(pageIcon);
	end

	self.packList = Lua_DragList.new(self.content, 2, Vector4(0, 0, 553, 302));
	self.packList:setListCell(Lua_ExquisitePagodaPackItem, 302, 553, 1000);
	self.packList:setCellScaleChange(true, 1, 1, 553, self, self.onPageCallBack);
	self.packList:setLocation(0, 30, 0);
	self.packList:moveToIndex(1, true);

	self.clearUpBtn:addClickFuntion(self, self.onClearUpBtnClick);
	self.pickUpBtn:addClickFuntion(self, self.onPickUpBtnClick);

	self:updatePackData();

	self:addLuaEvent("PACK_UPDATE", self, self.onPackDataUpdate);
end

function Lua_ExquisitePagodaPackWindow:updatePackData()
	local arr = Array();
	for i = 1, self.pageLen do
		arr:add({page = i, startIndex = (i - 1) * 28});
	end
	self.packList:setLuaArrayData(arr);	
end

function Lua_ExquisitePagodaPackWindow:onPackDataUpdate(packType)
	if packType == Lua_PackData.PAGODA_PACK then -- 临时仓库更新
		self:updatePackData();
	end
end

function Lua_ExquisitePagodaPackWindow:onPageClick(go)
	self.packList:moveToIndex(tonumber(go.name));
end

function Lua_ExquisitePagodaPackWindow:onPageCallBack(val)
	local len = self.pageTipList:getSize();
	for i = 1, len do
		if i == val then
			self.pageTipList[i]:setAltas("common_atlas_1", "ui_common_b_2");
		else
			self.pageTipList[i]:setAltas("common_atlas_1", "ui_common_b_1");
		end
	end
end

function Lua_ExquisitePagodaPackWindow:onClearUpBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	Lua_ProxyManager.getProxy("Lua_ExquisitePagodaProxy"):sPagodaPackClearUp(Lua_PackData.PAGODA_PACK);
end

function Lua_ExquisitePagodaPackWindow:onPickUpBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	local bagData = DataCenter.packData:getBagType(Lua_PackData.PAGODA_PACK);
	local arr = bagData:getBagAllData();
	if arr:getSize() <= 0 then
		OperateAlert.show(LanUtil.getValue(121428));
		return;
	end

	-- 一键取出
	Lua_ProxyManager.getProxy("Lua_ExquisitePagodaProxy"):sPagodaPackPickUp(1, 0, Lua_PackData.PAGODA_PACK);
end

function Lua_ExquisitePagodaPackWindow:dispose()
	if self.packList ~= nil then
		self.packList:dispose()
		self.packList = nil;
	end
	if self.pageTipList ~= nil then
		self.pageTipList:dispose();
		self.pageTipList:clear();
		self.pageTipList = nil;
	end
	Lua_ProxyManager.getProxy("Lua_ExquisitePagodaProxy"):sPagodaPackClearUp(Lua_PackData.PAGODA_PACK);
	
	self:superCall("dispose");
end





--------------------------------------------------





Lua_ExquisitePagodaPackItem = class("Lua_ExquisitePagodaPackItem", Lua_ListCell);
function Lua_ExquisitePagodaPackItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ExquisitePagodaPackItem:buildShowItem()
	self:superCall("buildShowItem");

	self.lastClickIndex = -1;
	self.lastClickTime = 0;

	local cell;
	local perWidth = 81;
	local perHeight = 79;
	local startX = -perWidth * (7 - 1) / 2;
	local startY = perHeight * (4 - 1) / 2;
	self.cells = Array();
	for j = 1, 4 do
		for i = 1, 7 do
			cell = Lua_ToolImage.new(self.content);
			cell.content.name = "cell"..(i + (j - 1) * 7);
			cell.defaultRoundEffect = true;
			cell:setDepth(4);
			cell:setScale(0.8, 0.8);
			cell:setCanClick(false);
			cell:setLocation(startX + (i - 1) * perWidth, startY - (j - 1) * perHeight, 0);
			self.cells:add(cell);
		end
	end

	local itemWidth = self.cells[1].item_bg.width * 0.8 / 2;
	local itemHeight = self.cells[1].item_bg.height * 0.8 / 2;
	self.cellPosX = Array();
	for i = 1, 7 do
		self.cellPosX:add({startX + (i - 1) * perWidth - itemWidth, startX + (i - 1) * perWidth + itemWidth});
	end

	self.cellPosY = Array();
	for i = 1, 4 do
		self.cellPosY:add({startY - (i - 1) * perHeight - itemHeight, startY - (i - 1) * perHeight + itemHeight});
	end
end

function Lua_ExquisitePagodaPackItem:setData(data)
	if data == nil then
		return;
	end
	self.startIndex = data.startIndex;

	local curIndex;
	local bagData = DataCenter.packData:getBagType(Lua_PackData.PAGODA_PACK);
	local packSize = bagData.packSize == nil and DataCenter.treasureUtil:getStoreSize() or bagData.packSize;
	for i = 1, self.cells:getSize() do
		curIndex = data.startIndex + i - 1;
		if curIndex >= packSize then
			self.cells[i].data = nil;
			self.cells[i]:setEnable(false);
		else
			self.cells[i].data = bagData:getItemByIndex(curIndex);
			self.cells[i]:setEnable(true);
		end
	end
end

function Lua_ExquisitePagodaPackItem:checkOutBound(showRect)
	for i = 1, self.cells:getSize() do
		if self.cells[i].data ~= nil then
			local rect = Lua_Rectangle.new(self.itemX + self.cells[i].x - 35, self.itemY + self.cells[i].y - 35, 70, 70);
			self.cells[i]:showRoundEffectView(showRect:containeRect(rect));
		end
	end
end

function Lua_ExquisitePagodaPackItem:onPlayerSoundClick()
	local inputPos = Vector3(UnityEngine.Input.mousePosition.x, UnityEngine.Input.mousePosition.y, 0);
	local screenpos = UICamera.mainCamera:ScreenToWorldPoint(inputPos);
	local mousePosition = self.content.transform:InverseTransformPoint(screenpos);
	
	local cx = 0;
	for i = 1, self.cellPosX:getSize() do
		if self.cellPosX[i][1] <= mousePosition.x and self.cellPosX[i][2] >= mousePosition.x then
			cx = i;
			break;
		end
	end

	if cx == 0 then
		return;
	end

	local cy = 0;
	for i = 1, self.cellPosY:getSize() do
		if self.cellPosY[i][1] <= mousePosition.y and self.cellPosY[i][2] >= mousePosition.y then
			cy = i;
			break;
		end
	end

	if cy == 0 then
		return;
	end

	self.clickIndex = cx + (cy - 1) * 7;
	if self.lastClickIndex ~= self.clickIndex or getTime() - self.lastClickTime > 0.3 then
		self.lastClickTime = getTime();
		self.lastClickIndex = self.clickIndex;
		Lua_CommonUtil.delayCall(0.3, self, self.onSingleClick);
	else
		Lua_CommonUtil.removeTimer(self, self.onSingleClick);
		self:onGetOutGoods();
		self.lastClickTime = -1;
	end
end

-- 取出
function Lua_ExquisitePagodaPackItem:onGetOutGoods()
	local tvo = self.cells[self.clickIndex].data;
	if tvo == nil then
		return;
	end

	Lua_ProxyManager.getProxy("Lua_ExquisitePagodaProxy"):sPagodaPackPickUp(0, tvo.index, Lua_PackData.PAGODA_PACK);
end

-- 展示tips
function Lua_ExquisitePagodaPackItem:onSingleClick()
	local tvo = self.cells[self.clickIndex].data;
	if tvo == nil then
		return;
	end

	Lua_PackUtil.showItemInfo(tvo);
end

function Lua_ExquisitePagodaPackItem:dispose()
	if self.cells ~= nil then
		self.cells:dispose();
		self.cells:clear();
		self.cells = nil;
	end
	Lua_CommonUtil.removeTimer(self, self.onSingleClick);

	self:superCall("dispose");
end