Lua_ExquisitePagodaPanel = class("Lua_ExquisitePagodaPanel", Lua_DisplayObject);
function Lua_ExquisitePagodaPanel:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ExquisitePagodaPanel:buildShowItem()
	self:superCall("buildShowItem");

	local arr = DataCenter.exquisitePagodaData.getLayerRewards;
	local pos = {{-155, -122}, {-95, -122}, {-35, -122}, {25, -122}, {85, -122}, {145, -122},
				{-125, -64}, {-65, -64}, {-5, -64}, {55, -64}, {115, -64},
				{-95, -6}, {-35, -6}, {25, -6}, {85, -6},
				{-65, 52}, {-5, 52}, {55, 52},
				{-35, 110}, {25, 110},
				{-5, 168}};
	local item;
	self.itemArr = Array();
	for i = 1, arr:getSize() do
		item = Lua_ExquisitePagodaShowIcon.new(self.content);
		item.content.name = "Lua_ExquisitePagodaShowIcon"..i;
		item:setDepth(4);
		item:setLocation(pos[i][1], pos[i][2], 0);
		item:setScale(0.6, 0.6);
		item:setData(arr[i]);
		self.itemArr:add(item);
	end
	self.totalLayer = (math.sqrt(8 * arr:getSize() + 1) - 1) / 2; -- n(n + 1) / 2 = arr:getSize()

	self:addLuaEvent("rEXQUISITE_PAGODA_DRAW_RESULT", self, self.updateDrawResult);
end

function Lua_ExquisitePagodaPanel:updateShow()
	for i = 1, self.itemArr:getSize() do
		self.itemArr[i]:updateSelectState(false);
	end

	local cur_layer = DataCenter.exquisitePagodaData.cur_layer;
	if cur_layer ~= DataCenter.exquisitePagodaData.draw_layer then
		local count = (self.totalLayer + 1 - cur_layer);
		local minusNum = self.itemArr:getSize() - count * (count + 1) / 2;
		self.itemArr[minusNum + 1]:updateSelectState(true);
	else
		local index = DataCenter.exquisitePagodaData.draw_index;
		if index ~= 0 and self.itemArr[index] ~= nil then
			self.itemArr[index]:updateSelectState(true);
		end
	end
end

function Lua_ExquisitePagodaPanel:updateDrawResult(msg)
	local index = msg.index + 1;
	if index > self.itemArr:getSize() then
		return;
	end

	for i = 1, self.itemArr:getSize() do
		self.itemArr[i]:updateSelectState(false);
	end
	DataCenter.exquisitePagodaData.isDraw = true; -- 特效显示中不可寻宝

	local layer = msg.layer;
	local count = (self.totalLayer + 1 - layer);
	local minusNum = self.itemArr:getSize() - count * (count + 1) / 2; -- 0, 6, 11, 15, 18, 20
	self.endIdx = index + minusNum; -- 抽中位置

	if DataCenter.exquisitePagodaData.isPass == 1 or layer == self.totalLayer then
		self:showOrHideLight(); -- 跳过动画或者最后一个，抽中直接三闪
	else
		self.time = 0.1;
		self.start = 1 + minusNum; -- 开始位置
		self.finish = self.start + self.totalLayer - layer; -- 结束位置
		self.showIdx = self.start;
		self.hideIdx = self.start;
		self.showTime = index + count * 2 - 1;
		self.hideTime = index + count * 2 - 1;
		Lua_CommonUtil.addTimer("Lua_ExquisitePagodaPanel_Show", self.time, self, self.effectShow);

		self.pauseTime = 1;
		Lua_CommonUtil.addTimer("Lua_ExquisitePagodaPanel_Pause", self.time, self, self.effectPause);
	end
end

function Lua_ExquisitePagodaPanel:effectShow()
	if self.showIdx > self.finish then
		self.showIdx = self.start;
	end
	
	self.showTime = self.showTime - 1;
	if self.showTime < 0 then
		Lua_CommonUtil.removeTimer(self, self.effectShow);
	else
		self.itemArr[self.showIdx]:updateSelectState(true);
		self.showIdx = self.showIdx + 1;
	end
end

function Lua_ExquisitePagodaPanel:effectPause()
	self.pauseTime = self.pauseTime - 1;
	if self.pauseTime <= 0 then
		Lua_CommonUtil.removeTimer(self, self.effectPause);
		Lua_CommonUtil.addTimer("Lua_ExquisitePagodaPanel_Hide", self.time, self, self.effectHide);
	end
end

function Lua_ExquisitePagodaPanel:effectHide()
	if self.hideIdx > self.finish then
		self.hideIdx = self.start;
	end
	
	self.hideTime = self.hideTime - 1;
	if self.hideTime < 0 then
		Lua_CommonUtil.removeTimer(self, self.effectHide);
		self:showOrHideLight();
	else
		self.itemArr[self.hideIdx]:updateSelectState(false);
		self.hideIdx = self.hideIdx + 1;
	end
end

-- 抽中位置三闪
function Lua_ExquisitePagodaPanel:showOrHideLight()
	self.itemArr[self.endIdx]:updateSelectState(true);

	self.showTimes = 3;
	self.showState = true;
	Lua_CommonUtil.addTimer("Lua_ExquisitePagodaPanel_threeLight", 0.1, self, self.updateShowOrHideState);
end

function Lua_ExquisitePagodaPanel:updateShowOrHideState()
	self.showTimes = self.showTimes - 1;
	self.showState = not self.showState;
	self.itemArr[self.endIdx]:updateSelectState(self.showState);

	if self.showTimes < 0 then
		Lua_CommonUtil.removeTimer(self, self.updateShowOrHideState);
		Lua_ProxyManager.getProxy("Lua_ExquisitePagodaProxy"):sExquisitePagodaDrawEnd(); -- 玲珑宝塔完成抽奖
	end
end

function Lua_ExquisitePagodaPanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.effectShow);
	Lua_CommonUtil.removeTimer(self, self.effectPause);
	Lua_CommonUtil.removeTimer(self, self.effectHide);
	Lua_CommonUtil.removeTimer(self, self.updateShowOrHideState);

	self:superCall("dispose");
end





--------------------------------------------------





Lua_ExquisitePagodaShowIcon = class("Lua_ExquisitePagodaShowIcon", Lua_DisplayObject);
function Lua_ExquisitePagodaShowIcon:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ExquisitePagodaShowIcon:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
	self.itemImg:setDepth(5);
	self.itemImg:setLocation(0, 0, 0);

	self.tagIcon = UICreate.createUIAtlasImage(self.content, "exquisitePagoda_atlas", "ui_llbt_z_01", 40, 18, 0, 0);
	self.tagIcon:setDepth(15);
	self.tagIcon:setEnable(false);

	self.selectedIcon = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_xzk", 0, 0, 90, 90);
	self.selectedIcon:setDepth(10);
	self.selectedIcon:setEnable(false);
end

function Lua_ExquisitePagodaShowIcon:setData(data)
	self._data = data;
	if data == nil then
		return;
	end
	
	self.itemImg.data = data.vo;
	self.itemImg:showRoundEff(data.show_effect == 1);

	self.tagIcon:setEnable(data.isSpecial == 1);
end

function Lua_ExquisitePagodaShowIcon:updateSelectState(state)
	self.selectedIcon:setEnable(state);
end

function Lua_ExquisitePagodaShowIcon:dispose()
	if self.itemImg ~= nil then
		self.itemImg:dispose();
		self.itemImg = nil;
	end
	if self.tagIcon ~= nil then
		self.tagIcon:dispose();
		self.tagIcon = nil;
	end
	if self.selectedIcon ~= nil then
		self.selectedIcon:dispose();
		self.selectedIcon = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end