-- 累计消费
Lua_CumulativeConsumptionPanel = class("Lua_CumulativeConsumptionPanel", Lua_DisplayObject)
function Lua_CumulativeConsumptionPanel:ctor(p)
	self:superCall("ctor", p, "OpenCommonPanel_skin");
end

function Lua_CumulativeConsumptionPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.roleImg:setUrl("/images/common/ui_leijixiaofei.png");
	self.roleImg:SetDimensions(284, 418);
	self.roleImg:setLocation(-372, -30, 0);

	self.dragList = Lua_DragList.new(self.content,1, Vector4(0, 0, 747, 290));
	self.dragList:setListCell(Lua_CumulativeConsumptionItem, 121, 712, 1);
	self.dragList:setLocation(124, -105, 0);

	self:addLuaEvent("UPDATE_ACT_CUMULATIVE_CONSUMPTION", self, self.updatePanelInfo);
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sGetActivityInfo(Lua_OperationalActivitiesData.ACT_CUMULATIVE_CONSUMPTION);
end

function Lua_CumulativeConsumptionPanel:updatePanelInfo()
	local start_tick = tonumber(DataCenter.cumulativeConsumptionData.startTick);
	local end_tick = tonumber(DataCenter.cumulativeConsumptionData.endTick);
	local sTimeStr = TimeTransform.getInstance():transSeconds8(start_tick, "yyyy-MM-dd HH:mm");
	local eTimeStr = TimeTransform.getInstance():transSeconds8(end_tick, "yyyy-MM-dd HH:mm");
	self.open_time.text = LanUtil.formateStr(LanUtil.getValue(141702), tostring(sTimeStr .. "--" .. eTimeStr));

	local content = DataCenter.cumulativeConsumptionData.content;
	self.tips.text = LanUtil.formateStr(LanUtil.getValue(141704), tostring(content));

	Lua_CommonUtil.addTimer("CumulativeConsumption_ResidueTime", 1, self, self.updateResidueTime);
	self:updateResidueTime();

	local data = DataCenter.cumulativeConsumptionData.getTotalConsumeActData;
	self.dragList:setLuaArrayData(data, false);
end

-- 活动剩余时间
function Lua_CumulativeConsumptionPanel:updateResidueTime()
	local end_time = tonumber(DataCenter.cumulativeConsumptionData.endTick) - DataCenter.roleData.serverTime;
	if end_time > 0 then
		self.end_time.text = LanUtil.formateStr(LanUtil.getValue(141703), TimeTransform.getInstance():transSeconds1(end_time, true));
	else
		self.end_time.text = LanUtil.getValue(141705);
		Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
	end
end

function Lua_CumulativeConsumptionPanel:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose()
		self.dragList = nil;
	end
	Lua_CommonUtil.removeTimer(self, self.updateResidueTime);

	self:superCall("dispose");
end










Lua_CumulativeConsumptionItem = class("Lua_CumulativeConsumptionItem", Lua_ListCell);
function Lua_CumulativeConsumptionItem:ctor(p)
	self:superCall("ctor", p, "OpenCommonItem_skin");
end

function Lua_CumulativeConsumptionItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemArr = Array();

	self.redDot = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_hongdian", 330, 16, 0, 0);
	self.redDot.name = "redDot";
	self.redDot:setDepth(2);
	self.redDot:setEnable(false);

	self.subBtn:addClickFuntion(self, self.onSubBtnClick);
end

function Lua_CumulativeConsumptionItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local total_gold = tonumber(DataCenter.cumulativeConsumptionData.total_gold);
	local str;
	if total_gold >= tonumber(data.cond)  then
		str = "[00E125]" .. total_gold .. "[-]";
	else
		str = "[FF1616]" .. total_gold  .. "[-]";
	end
	self.titleTxt.text = LanUtil.formateStr(LanUtil.getValue(141701), str, tostring(data.cond));

	local maxNum = data.tvoArr:getSize() > self.itemArr:getSize() and data.tvoArr:getSize() or self.itemArr:getSize();
	local tvo;
	local itemImg;
	for i = 1, maxNum do
		itemImg = self.itemArr[i];
		if i <= data.tvoArr:getSize() then
			if itemImg == nil then
				itemImg = Lua_ToolImage.new(self.content);
				self.itemArr:add(itemImg);
			end
			itemImg.data = data.tvoArr[i];
			itemImg:setDepth(2);
			itemImg:setScale(0.77, 0.77, 0.77);
			itemImg:setLocation(-305 + (i - 1) * 85, -18, 0);
			itemImg:setEnable(true);
		else
			if itemImg ~= nil then
				itemImg:setEnable(false);
			end
		end
	end

	if data.state == 0 then -- 不可领取
		self.subBtn.label = LanUtil.getValue(141700);
	elseif data.state == 1 then -- 可领取
		self.subBtn.label = LanUtil.getValue(140714);
	elseif data.state == 2 then -- 已领取
		self.subBtn.label = LanUtil.getValue(140715);
	end
	self.subBtn:setBtnEnable(data.state ~= 2);
	self.redDot:setEnable(data.state == 1);
end

function Lua_CumulativeConsumptionItem:checkOutBound(showRect)
	local width = 75 * 0.77;
	local height = 77 * 0.77;
	local rect = Lua_Rectangle.new(self.itemX - width / 2, self.itemY - height / 2 - 18, width, height);
	local isShow = showRect:containeRect(rect);
	for i = 1, self.itemArr:getSize() do
		if self.itemArr[i].data.subType ~= Lua_PackTypeDefine.STAMP_ITEM then
			self.itemArr[i]:showRoundEff(isShow and self.itemArr[i].data.roundEffect);
		else
			self.itemArr[i]:showStampEff(isShow and self.itemArr[i].data.roundEffect);
		end
	end
end

function Lua_CumulativeConsumptionItem:onSubBtnClick()
	if self.data.state == 0 then -- 不可领取
		Lua_WindowUtil.openWin("Lua_ShopWindow", WinParam.ACTION_OPEN, nil);
	elseif self.data.state == 1 then -- 可领取
		local bagData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
		local leftNum = bagData:getLeftSize();
		if leftNum < self.data.tvoArr:getSize() then
			DataCenter.packData:showFullBagTip(Lua_PackData.BAG_PACK);
			return;
		end
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sGetActivityRewards(Lua_OperationalActivitiesData.ACT_CUMULATIVE_CONSUMPTION, self.data.index);
	end
end

function Lua_CumulativeConsumptionItem:dispose()
    self:superCall("dispose");
end