Lua_SuperExchangePanel = class("Lua_SuperExchangePanel", Lua_DisplayObject);
function Lua_SuperExchangePanel:ctor(p)
	self:superCall("ctor", p, nil);
end

function Lua_SuperExchangePanel:buildShowItem()
	self:superCall("buildShowItem");

	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sGetActivityInfo(Lua_OperationalActivitiesData.SUPER_EXCHANGE);

	self.end_time = UICreate.createLabel(self.content, "", 100, 210, 300, 30, 22);
    self.end_time.overflowMethod = UILabel.Overflow.ResizeFreely;
    self.end_time.pivot = UIWidget.Pivot.TopLeft;
    self.end_time:setDepth(2);

	local banner = UICreate.createImage(self.content, "/images/operationalActivities/ui_czdh_banner.png", 5, 119, 0, 0);
	banner:setDepth(2);
	local banner2 = UICreate.createImage(self.content, "/images/operationalActivities/ui_czdh_font.png", -57, 122, 0, 0);
	banner2:setDepth(3);

	self.dragList = Lua_DragList.new(self.content,1, Vector4(0, 0, 970, 338));
    self.dragList:setLocation(2, -108, 0);
    self.dragList:setListCell(Lua_ExchangeItem, 125, 970, 1);

    self:addLuaEvent("UPDATE_SUPER_EXCHANGE", self, self.updatePanelInfo);
end

function Lua_SuperExchangePanel:dispose()
	if self.dragList ~= nil then
        self.dragList:dispose()
        self.dragList = nil;
    end
	Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
	self:superCall("dispose");
end

function Lua_SuperExchangePanel:updatePanelInfo()
	Lua_CommonUtil.addTimer("Exchange_ResidueTime", 1, self, self.updateResidueTime, nil, -1);
	self:updateResidueTime();

	local arr = DataCenter.superExchangeData.getExchangeRewardData;
	self.dragList:setLuaArrayData(arr, false);
end

function Lua_SuperExchangePanel:updateResidueTime()
	local end_time = tonumber(DataCenter.superExchangeData.exchange_endTick) - DataCenter.roleData.serverTime;
	if end_time > 0 then
		self.end_time.text = LanUtil.formateStr(LanUtil.getValue(146008), TimeTransform.getInstance():transSeconds1(end_time, true));
	else
		self.end_time.text = LanUtil.getValue(146004);
		Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
	end
end



















Lua_ExchangeItem = class("Lua_ExchangeItem", Lua_ListCell);
function Lua_ExchangeItem:ctor(p)
    self:superCall("ctor", p, "SuperExchangeItem_skin");
end

function Lua_ExchangeItem:buildShowItem()
	self:superCall("buildShowItem");

	self.redDot:setEnable(false);
	self.subObj.gameObject:SetActive(false);
    self.subBtn:addClickFuntion(self, self.onSubBtnClick);

	self.rewardArr = Array();
end

function Lua_ExchangeItem:dispose()
    self:superCall("dispose");
end

function Lua_ExchangeItem:setData(data)
	self.data = data;

	if data.vip_lvl == 0 then
		self.titleTxt.text = LanUtil.getValue(145310);
	else
		self.titleTxt.text = LanUtil.formateStr(LanUtil.getValue(145300), tostring(data.vip_lvl));
	end
	self.prime_cost.text = LanUtil.formateStr(LanUtil.getValue(145301), tostring(data.prime_cost));
	self.current_price.text = LanUtil.formateStr(LanUtil.getValue(145302), tostring(data.cur_cost));

	local str = "";
	if data.cur_amount == data.total_amount then
		str = "[FF1616]"..data.cur_amount.."/"..data.total_amount.."[-]";
	else
		str = "[00E125]"..data.cur_amount.."/"..data.total_amount.."[-]";
	end
	self.condTxt.text = LanUtil.formateStr(LanUtil.getValue(145303), str);

	self:creationRewardCell();

	if data.cur_amount == data.total_amount then
		self.subBtn:setBtnEnable(false);
		self.subBtn.label = LanUtil.getValue(145305);
	else
		self.subBtn:setBtnEnable(true);
		self.subBtn.label = LanUtil.getValue(145304);
	end
end 

-- 创建奖励道具
function Lua_ExchangeItem:creationRewardCell()
	--print("creationRewardCell")
	local data = self.data.itemArr;
	self.len = data:getSize();
	local num = self.rewardArr:getSize() - self.len;

	local itemImg;
	while(num > 0) do
		itemImg = self.rewardArr:shift();
		itemImg:dispose();
		num = num - 1;
	end

	while (num < 0) do
		itemImg = Lua_ToolImage.new(self.content);
		itemImg:setDepth(5);
		itemImg:setScale(0.9, 0.9, 0.9);
		itemImg:setEnable(false);
		itemImg:setCanClick(true);
		self.rewardArr:add(itemImg);
		num = num + 1;
	end

	self:setItemImgData();
end

function Lua_ExchangeItem:setItemImgData()
	local sortNum = 1;
	for i=1, self.len do
		self.rewardArr[i]:setLocation(-427 + (sortNum - 1) * 80, -17, 0);
		self.rewardArr[i].data = self.data.itemArr[i].vo;
		self.rewardArr[i]:setEnable(true);
		if self.data.itemArr[i].show_effect == 1 then
			self.rewardArr[i]:showRoundEff(true);
			if roundEff ~= nil then
				self.rewardArr[i].roundEff:setSacle(0.9,0.9,0.9);
				self.rewardArr[i].roundEff:SetRenderQueue(self.rewardArr[i].item_bg, 5, 2, true);
			end
		end
		sortNum = sortNum + 1;
	end
end

function Lua_ExchangeItem:checkOutBound(showRect)
	local len = self.rewardArr:getSize();
	for i=1,len do
		local rect = Lua_Rectangle.new(self.itemX, self.itemY - 35, 25, 60);
		if self.rewardArr[i].roundEff ~= nil then
			if showRect:containeRect(rect) == true then
				self.rewardArr[i].roundEff:setEnable(true);
			else
				self.rewardArr[i].roundEff:setEnable(false);
			end
		end

		if self.rewardArr[i].data.subType == Lua_PackTypeDefine.STAMP_ITEM then
			if self.rewardArr[i].stampEff ~= nil then
				if showRect:containeRect(rect) == true then
					self.rewardArr[i].stampEff:setEnable(true);
				else
					self.rewardArr[i].stampEff:setEnable(false);
				end
			end
		end
		
		if self.rewardArr[i].data.subType == Lua_PackTypeDefine.ARMY_EQUIP_ITEM then
			if self.rewardArr[i].armyEff ~= nil then
				if showRect:containeRect(rect) == true then
					self.rewardArr[i].armyEff:setEnable(true);
				else
					self.rewardArr[i].armyEff:setEnable(false);
				end
			end
		end
	end
end

function Lua_ExchangeItem:onSubBtnClick()
	if DataCenter.vipData.level < self.data.vip_lvl then
		OperateAlert.show(LanUtil.getValue(145308));
		return;
	end
	
	local str = "";
    if DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD) < self.data.cur_cost then
        str = "["..Lua_ColorDefine.RED_STR.."]"..self.data.cur_cost.."[-]";
        self.enoughMoney = false;
    else
        str = "["..Lua_ColorDefine.GREEN_STR.."]"..self.data.cur_cost.."[-]";
        self.enoughMoney = true;
    end

    local tipData = {};
    tipData.des = LanUtil.formateStr(LanUtil.getValue(145309), str);
    tipData.owner = self;
    tipData.type = 1;
    tipData.subFun = self.onSureFun;   --确定
    Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
end

function Lua_ExchangeItem:onSureFun()
    if self.enoughMoney == false then
        DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.data.cur_cost, true, true);
    else
        Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sSuperExchange(self.data.index);
    end
end