Lua_SuperReturnPanel = class("Lua_SuperReturnPanel", Lua_DisplayObject);
function Lua_SuperReturnPanel:ctor(p)
	self:superCall("ctor", p, nil);
end

function Lua_SuperReturnPanel:buildShowItem()
	self:superCall("buildShowItem");

	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sGetActivityInfo(Lua_OperationalActivitiesData.SUPER_RETURN);

	self.end_time = UICreate.createLabel(self.content, "", 100, 210, 300, 30, 22);
	self.end_time.overflowMethod = UILabel.Overflow.ResizeFreely;
    self.end_time.pivot = UIWidget.Pivot.TopLeft;
    self.end_time:setDepth(2);

	local banner = UICreate.createImage(self.content, "/images/operationalActivities/ui_czdh_banner.png", 5, 119, 0, 0);
	banner:setDepth(2);
	local banner2 = UICreate.createImage(self.content, "/images/operationalActivities/ui_czdh_font1.png", -57, 122, 0, 0);
	banner2:setDepth(3);

	self.dragList = Lua_DragList.new(self.content,1, Vector4(0, 0, 970, 338));
    self.dragList:setLocation(2, -108, 0);
    self.dragList:setListCell(Lua_SuperReturnItem, 125, 970, 1);

    self:addLuaEvent("UPDATE_SUPER_RETURN", self, self.updatePanelInfo);
end

function Lua_SuperReturnPanel:dispose()
	if self.dragList ~= nil then
        self.dragList:dispose()
        self.dragList = nil;
    end
	Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
	self:superCall("dispose");
end

function Lua_SuperReturnPanel:updatePanelInfo()
	Lua_CommonUtil.addTimer("Return_ResidueTime", 1, self, self.updateResidueTime, nil, -1);
	self:updateResidueTime();

	local arr = DataCenter.superExchangeData.getReturnRewardData;
	self.dragList:setLuaArrayData(arr, false);
end

function Lua_SuperReturnPanel:updateResidueTime()
	local end_time = tonumber(DataCenter.superExchangeData.return_endTick) - DataCenter.roleData.serverTime;
	if end_time > 0 then
		self.end_time.text = LanUtil.formateStr(LanUtil.getValue(146008), TimeTransform.getInstance():transSeconds1(end_time, true));
	else
		self.end_time.text = LanUtil.getValue(146004);
		Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
	end
end



















Lua_SuperReturnItem = class("Lua_SuperReturnItem", Lua_ListCell);
function Lua_SuperReturnItem:ctor(p)
    self:superCall("ctor", p, "SuperExchangeItem_skin");
end

function Lua_SuperReturnItem:buildShowItem()
	self:superCall("buildShowItem");

	self.condTxt:setEnable(false);
	self.costObj.gameObject:SetActive(false);
	self.subObj.gameObject:SetActive(false);
	self.subBtn:setEnable(false);
    self.subBtn:addClickFuntion(self, self.onSubBtnClick);

	self.rewardArr = Array();
end

function Lua_SuperReturnItem:dispose()
    self:superCall("dispose");
end

function Lua_SuperReturnItem:setData(data)
	self.data = data;

	local str = "";
	if data.cur_amount >= data.cond_amount then
		str = "[00E125]"..data.cur_amount.."[-]";
	else
		str = "[FF1616]"..data.cur_amount.."[-]";
	end
	self.titleTxt.text = LanUtil.formateStr(LanUtil.getValue(145306), data.itemName, str, tostring(data.cond_amount));

	self:creationRewardCell();

	if data.state == 0 then
		self.redDot:setEnable(false);
		self.subBtn:setEnable(true);
		self.subBtn.label = LanUtil.getValue(145307);
		self.subObj.gameObject:SetActive(false);
	elseif data.state == 1 then -- 可领取
		self.redDot:setEnable(true);
		self.subBtn:setEnable(true);
		self.subBtn.label = LanUtil.getValue(140714);
		self.subObj.gameObject:SetActive(false);
	elseif data.state == 2 then -- 已领取
		self.redDot:setEnable(false);
		self.subBtn:setEnable(false);
		self.subObj.gameObject:SetActive(true);
	end
end 

-- 创建奖励道具
function Lua_SuperReturnItem:creationRewardCell()
	local data = self.data.itemArr;
	self.len = data:getSize();
	local num = self.rewardArr:getSize() - self.len;

	local itemImg;
	while(num > 0) do
		itemImg = self.rewardArr:shift();
		itemImg:dispose();
		num = num - 1;
	end

	while (num < 0) do
		itemImg = Lua_ToolImage.new(self.content);
		itemImg:setDepth(5);
		itemImg:setScale(0.9, 0.9, 0.9);
		itemImg:setEnable(false);
		itemImg:setCanClick(true);
		self.rewardArr:add(itemImg);
		num = num + 1;
	end

	self:setItemImgData();
end

function Lua_SuperReturnItem:setItemImgData()
	local sortNum = 1;
	for i=1, self.len do
		self.rewardArr[i]:setLocation(-427 + (sortNum - 1) * 80, -17, 0);
		self.rewardArr[i].data = self.data.itemArr[i].vo;
		self.rewardArr[i]:setEnable(true);
		if self.data.itemArr[i].show_effect == 1 then
			self.rewardArr[i]:showRoundEff(true);
			if roundEff ~= nil then
				self.rewardArr[i].roundEff:setSacle(0.9,0.9,0.9);
				self.rewardArr[i].roundEff:SetRenderQueue(self.rewardArr[i].item_bg, 5, 2, true);
			end
		end
		sortNum = sortNum + 1;
	end
end

function Lua_SuperReturnItem:checkOutBound(showRect)
	local len = self.rewardArr:getSize();
	for i=1,len do
		local rect = Lua_Rectangle.new(self.itemX, self.itemY - 35, 25, 60);
		if self.rewardArr[i].roundEff ~= nil then
			if showRect:containeRect(rect) == true then
				self.rewardArr[i].roundEff:setEnable(true);
			else
				self.rewardArr[i].roundEff:setEnable(false);
			end
		end

		if self.rewardArr[i].data.subType == Lua_PackTypeDefine.STAMP_ITEM then
			if self.rewardArr[i].stampEff ~= nil then
				if showRect:containeRect(rect) == true then
					self.rewardArr[i].stampEff:setEnable(true);
				else
					self.rewardArr[i].stampEff:setEnable(false);
				end
			end
		end
		
		if self.rewardArr[i].data.subType == Lua_PackTypeDefine.ARMY_EQUIP_ITEM then
			if self.rewardArr[i].armyEff ~= nil then
				if showRect:containeRect(rect) == true then
					self.rewardArr[i].armyEff:setEnable(true);
				else
					self.rewardArr[i].armyEff:setEnable(false);
				end
			end
		end
	end
end

function Lua_SuperReturnItem:onSubBtnClick()
	if self.data.state == 0 then
		if DataCenter.funcOpenData:isOpened(self.data.funcOpenId, true) == false then
			return;
		end
		
		Lua_WindowUtil.openWin("Lua_GrandCeremonyWindow", WinParam.ACTION_CLOSE);
		Lua_WindowUtil.openWin("Lua_SuperExchangeWindow", WinParam.ACTION_CLOSE);
		Lua_WindowUtil.openWin(self.data.winName, WinParam.ACTION_OPEN, self.data.winIndex);
	elseif self.data.state == 1 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sGetActivityRewards(Lua_OperationalActivitiesData.SUPER_RETURN, self.data.index);
	end
end